View Source Avatador.Helpers.Color (avatador v0.1.0)

Color Helpers

Link to this section Summary

Functions

Convert Hex to RGB Returns a Map; %{r: dec_red, g: dec_green, b: dec_blue, a: dec_alpha} https://github.com/barakyo/color_utils

Checks if given color is a valid color hex i.e. #FFFFFF.

Link to this section Functions

Convert Hex to RGB Returns a Map; %{r: dec_red, g: dec_green, b: dec_blue, a: dec_alpha} https://github.com/barakyo/color_utils

Link to this function

is_valid_color_hex?(color)

View Source (since 0.1.0)

Checks if given color is a valid color hex i.e. #FFFFFF.