View Source Avatador.Helpers.List (avatador v0.1.0)

List Helpers

Link to this section Summary

Functions

Turn a list of binary encoded hexadecimal into a 5x5 grid. Mirroring of each row is applied to create symmetry.

Mirror a List. e.g. [1, 2, 3] -> [1, 2, 3, 2, 1]

Link to this section Functions

Link to this function

integer_list_to_grid(list)

View Source (since 0.1.0)

Turn a list of binary encoded hexadecimal into a 5x5 grid. Mirroring of each row is applied to create symmetry.

Link to this function

mirror(row)

View Source (since 0.1.0)

Mirror a List. e.g. [1, 2, 3] -> [1, 2, 3, 2, 1]