View Source Avatador.Helpers.List (avatador v0.1.0)
List Helpers
Link to this section Summary
Link to this section Functions
Turn a list of binary encoded hexadecimal into a 5x5 grid. Mirroring of each row is applied to create symmetry.
Mirror a List.
e.g. [1, 2, 3] -> [1, 2, 3, 2, 1]